@@ -31,7 +31,6 @@
 #include "bstmenus.h"
 #include "bstprocedure.h"
 #include "bstprojectctrl.h"
-#include "sfi/toyprof-mem.h"
 
 
 /* --- prototypes --- */
@@ -497,20 +496,20 @@ bst_app_update_can_operate (BstApp *app)
     return;
 
   shell = bst_app_get_current_shell (app);
-  widget = gtk_item_factory_get_item (bst_app_menu_factory (app), "/Song");
+  widget = gxk_item_factory_get_item (bst_app_menu_factory (app), "/Song");
   if (widget)
     gtk_widget_set_sensitive (widget, BST_IS_SONG_SHELL (shell));
-  widget = gtk_item_factory_get_item (bst_app_menu_factory (app), "/Waves");
+  widget = gxk_item_factory_get_item (bst_app_menu_factory (app), "/Waves");
   if (widget)
     gtk_widget_set_sensitive (widget, BST_IS_WAVE_REPO_SHELL (shell));
 
-  widget = gtk_item_factory_get_item (bst_app_menu_factory (app), "/File/Save");	// FIXME: hack
+  widget = gxk_item_factory_get_item (bst_app_menu_factory (app), "/File/Save");	// FIXME: hack
   if (widget)
     gtk_widget_set_sensitive (widget, BST_IS_SONG_SHELL (shell));
-  widget = gtk_item_factory_get_item (bst_app_menu_factory (app), "/Edit/Undo");	// FIXME: hack
+  widget = gxk_item_factory_get_item (bst_app_menu_factory (app), "/Edit/Undo");	// FIXME: hack
   if (widget)
     gtk_widget_set_sensitive (widget, BST_IS_SONG_SHELL (shell));
-  widget = gtk_item_factory_get_item (bst_app_menu_factory (app), "/Edit/Redo");	// FIXME: hack
+  widget = gxk_item_factory_get_item (bst_app_menu_factory (app), "/Edit/Redo");	// FIXME: hack
   if (widget)
     gtk_widget_set_sensitive (widget, BST_IS_SONG_SHELL (shell));
 
@@ -731,7 +730,6 @@ bst_app_operate (BstApp *app,
 			    any);
       gtk_widget_show (any);
       sfi_alloc_report ();
-      toyprof_report_mem ();
 #if 0 // FIXME
       {
 	GSList *slist, *olist = g_object_debug_list();
@@ -926,10 +924,10 @@ bst_update_can_operate (GtkWidget *widget)
   /* figure toplevel app, and update it
    */
   widget = gtk_widget_get_ancestor (widget, BST_TYPE_APP);
-  g_return_if_fail (BST_IS_APP (widget));
-
-  op_update_list = g_slist_prepend (op_update_list, g_object_ref (widget));
-
-  if (!op_update_id)
-    op_update_id = g_idle_add_full (-1000, op_update_handler, NULL, NULL);
+  if (BST_IS_APP (widget) && !g_slist_find (op_update_list, widget))
+    {
+      op_update_list = g_slist_prepend (op_update_list, g_object_ref (widget));
+      if (!op_update_id)
+	op_update_id = g_idle_add_full (G_PRIORITY_DEFAULT, op_update_handler, NULL, NULL);
+    }
 }
