@@ -17,9 +17,6 @@
  */
 #include "bstcanvaslink.h"
 
-#include "bstdialog.h"
-#include "bsttexttools.h"
-
 #include <math.h>
 
 #define ARROW_LENGTH    (12.0)
@@ -164,59 +161,59 @@ clink_view_update (BstCanvasLink *clink,
 		   gboolean       force_update)
 {
   GtkWidget *frame = (clink->link_view && (force_update || GTK_WIDGET_VISIBLE (clink->link_view))
-		      ? bst_dialog_get_child (BST_DIALOG (clink->link_view))
+		      ? gxk_dialog_get_child (GXK_DIALOG (clink->link_view))
 		      : NULL);
 
   if (frame)
     {
       GtkWidget *text = GTK_BIN (frame)->child;
-      gchar *ic_name, *oc_name, *ic_blurb, *oc_blurb;
-      gchar *string, *iname, *oname;
+      const gchar *ic_name, *oc_name, *ic_blurb, *oc_blurb, *iname, *oname;
+      gchar *string;
 
       /* figure appropriate window title
        */
-      iname = clink->icsource ? bsw_item_get_name_or_type (clink->icsource->source) : "<???>";
-      oname = clink->ocsource ? bsw_item_get_name_or_type (clink->ocsource->source) : "<???>";
+      iname = clink->icsource ? bse_item_get_name_or_type (clink->icsource->source) : "<???>";
+      oname = clink->ocsource ? bse_item_get_name_or_type (clink->ocsource->source) : "<???>";
       string = g_strconcat ("Module Link: ", iname, " <=> ", oname, NULL);
-      bst_dialog_set_title (BST_DIALOG (clink->link_view), string);
+      gxk_dialog_set_title (GXK_DIALOG (clink->link_view), string);
       g_free (string);
 
       /* construct actuall information
        */
-      oc_name = clink->ocsource ? bsw_source_ochannel_name (clink->ocsource->source, clink->ochannel) : NULL;
-      oc_blurb = clink->ocsource ? bsw_source_ochannel_blurb (clink->ocsource->source, clink->ochannel) : NULL;
-      ic_name = clink->icsource ? bsw_source_ichannel_name (clink->icsource->source, clink->ichannel) : NULL;
-      ic_blurb = clink->icsource ? bsw_source_ichannel_blurb (clink->icsource->source, clink->ichannel) : NULL;
+      oc_name = clink->ocsource ? bse_source_ochannel_name (clink->ocsource->source, clink->ochannel) : NULL;
+      oc_blurb = clink->ocsource ? bse_source_ochannel_blurb (clink->ocsource->source, clink->ochannel) : NULL;
+      ic_name = clink->icsource ? bse_source_ichannel_name (clink->icsource->source, clink->ichannel) : NULL;
+      ic_blurb = clink->icsource ? bse_source_ichannel_blurb (clink->icsource->source, clink->ichannel) : NULL;
       if (!oc_name)
 	oc_name = "?";
       if (!ic_name)
 	ic_name = "?";
 
       /* compose new info */
-      bst_scroll_text_clear (text);
-      bst_scroll_text_aprintf (text, "Source Module:\n");
-      bst_scroll_text_push_indent (text, "  ");
+      gxk_scroll_text_clear (text);
+      gxk_scroll_text_aprintf (text, "Source Module:\n");
+      gxk_scroll_text_push_indent (text);
       if (oc_blurb)
 	{
-	  bst_scroll_text_aprintf (text, "%s: %s:\n", oname, oc_name);
-	  bst_scroll_text_push_indent (text, "  ");
-	  bst_scroll_text_aprintf (text, "%s\n", oc_blurb);
-	  bst_scroll_text_pop_indent (text);
+	  gxk_scroll_text_aprintf (text, "%s: %s:\n", oname, oc_name);
+	  gxk_scroll_text_push_indent (text);
+	  gxk_scroll_text_aprintf (text, "%s\n", oc_blurb);
+	  gxk_scroll_text_pop_indent (text);
 	}
       else
-	bst_scroll_text_aprintf (text, "%s: %s\n", oname, oc_name);
-      bst_scroll_text_pop_indent (text);
-      bst_scroll_text_aprintf (text, "\nDestination Module:\n");
-      bst_scroll_text_push_indent (text, "  ");
+	gxk_scroll_text_aprintf (text, "%s: %s\n", oname, oc_name);
+      gxk_scroll_text_pop_indent (text);
+      gxk_scroll_text_aprintf (text, "\nDestination Module:\n");
+      gxk_scroll_text_push_indent (text);
       if (ic_blurb)
 	{
-	  bst_scroll_text_aprintf (text, "%s: %s:\n", iname, ic_name);
-	  bst_scroll_text_push_indent (text, "  ");
-	  bst_scroll_text_aprintf (text, "%s\n", ic_blurb);
-	  bst_scroll_text_pop_indent (text);
+	  gxk_scroll_text_aprintf (text, "%s: %s:\n", iname, ic_name);
+	  gxk_scroll_text_push_indent (text);
+	  gxk_scroll_text_aprintf (text, "%s\n", ic_blurb);
+	  gxk_scroll_text_pop_indent (text);
 	}
       else
-	bst_scroll_text_aprintf (text, "%s: %s\n", iname, ic_name);
+	gxk_scroll_text_aprintf (text, "%s: %s\n", iname, ic_name);
     }
 }
 
@@ -226,7 +223,7 @@ bst_canvas_link_popup_view (BstCanvasLink *clink)
   g_return_if_fail (BST_IS_CANVAS_LINK (clink));
   
   if (!clink->link_view)
-    clink->link_view = bst_dialog_new (&clink->link_view,
+    clink->link_view = gxk_dialog_new (&clink->link_view,
 				       GTK_OBJECT (clink),
 				       0,
 				       NULL,
@@ -234,10 +231,10 @@ bst_canvas_link_popup_view (BstCanvasLink *clink)
 						       "visible", TRUE,
 						       "border_width", 5,
 						       "label", "Module link",
-						       "child", bst_scroll_text_create (0, NULL),
+						       "child", gxk_scroll_text_create (GXK_SCROLL_TEXT_WIDGET_LOOK, NULL),
 						       NULL));
   clink_view_update (clink, TRUE);
-  gtk_widget_showraise (clink->link_view);
+  gxk_widget_showraise (clink->link_view);
 }
 
 void
@@ -271,7 +268,7 @@ bst_canvas_link_set_ocsource (BstCanvasLink   *clink,
   if (clink->ocsource)
     {
       if (clink->ocsource->source) /* source may be destroyed already */
-	bsw_proxy_disconnect (clink->ocsource->source,
+	bse_proxy_disconnect (clink->ocsource->source,
 			      "any_signal", clink_view_check_update, clink,
 			      NULL);
       if (g_signal_handler_is_connected (clink->ocsource, clink->oc_handler))
@@ -287,8 +284,8 @@ bst_canvas_link_set_ocsource (BstCanvasLink   *clink,
 						     "notify",
 						     G_CALLBACK (bst_canvas_link_update),
 						     GTK_OBJECT (clink));
-      bsw_proxy_connect (clink->ocsource->source,
-			 "swapped_signal::notify::uname", clink_view_check_update, clink,
+      bse_proxy_connect (clink->ocsource->source,
+			 "swapped_signal::property-notify::uname", clink_view_check_update, clink,
 			 NULL);
       bst_canvas_link_update (clink);
     }
@@ -306,7 +303,7 @@ bst_canvas_link_set_icsource (BstCanvasLink   *clink,
   if (clink->icsource)
     {
       if (clink->icsource->source) /* source may be destroyed already */
-	bsw_proxy_disconnect (clink->icsource->source,
+	bse_proxy_disconnect (clink->icsource->source,
 			      "any_signal", clink_view_check_update, clink,
 			      NULL);
       if (g_signal_handler_is_connected (clink->icsource, clink->ic_handler))
@@ -322,8 +319,8 @@ bst_canvas_link_set_icsource (BstCanvasLink   *clink,
 						     "notify",
 						     G_CALLBACK (bst_canvas_link_update),
 						     GTK_OBJECT (clink));
-      bsw_proxy_connect (clink->icsource->source,
-			 "swapped_signal::notify::uname", clink_view_check_update, clink,
+      bse_proxy_connect (clink->icsource->source,
+			 "swapped_signal::property-notify::uname", clink_view_check_update, clink,
 			 NULL);
       bst_canvas_link_update (clink);
     }
