@@ -1,5 +1,5 @@
 /* BEAST - Bedevilled Audio System
- * Copyright (C) 1998-2002 Tim Janik
+ * Copyright (C) 1998-2003 Tim Janik
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,15 +18,12 @@
 #ifndef __BST_DEFS_H__
 #define __BST_DEFS_H__
 
-#include	"bstutils.h"
-#include	"gtklistwrapper.h"
-#include	"glewidgets.h"
-#include	"bstzoomedwindow.h"
-#include	"bstfreeradiobutton.h"
+#include <gxk/gxk.h>
+#include "glewidgets.h"
+#include "bstzoomedwindow.h"
+#include "bstfreeradiobutton.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 
 /* --- BEAST mainmenu operations --- */
@@ -38,6 +35,7 @@ typedef enum
    */
   BST_OP_PROJECT_NEW,
   BST_OP_PROJECT_OPEN,
+  BST_OP_PROJECT_MERGE,
   BST_OP_PROJECT_SAVE,
   BST_OP_PROJECT_SAVE_AS,
   BST_OP_PROJECT_NEW_SONG,
@@ -56,7 +54,6 @@ typedef enum
 
   /* debugging */
   BST_OP_REBUILD,
-  BST_OP_REFRESH,
 
   /* song operations
    */
@@ -92,18 +89,26 @@ typedef enum
   BST_OP_LAST
 } BstOps;
 
+typedef enum {
+  BST_QUANTIZE_NONE		= 0,
+  BST_QUANTIZE_NOTE_1		= 1,
+  BST_QUANTIZE_NOTE_2		= 2,
+  BST_QUANTIZE_NOTE_4		= 4,
+  BST_QUANTIZE_NOTE_8		= 8,
+  BST_QUANTIZE_NOTE_16		= 16,
+  BST_QUANTIZE_NOTE_32		= 32,
+  BST_QUANTIZE_NOTE_64		= 64,
+  BST_QUANTIZE_NOTE_128		= 128,
+  BST_QUANTIZE_TACT		= 65535
+} BstQuantizationType;
+
 
 /* --- constants & defines --- */
 #define	BST_TAG_DIAMETER	  (20)
 #define BST_STRDUP_RC_FILE()	  (g_strconcat (g_get_home_dir (), "/.beastrc", NULL))
-#define BST_BUTTON_ICON_WIDTH	  (32)
-#define BST_BUTTON_ICON_HEIGHT	  (32)
-#define BST_DRAG_ICON_WIDTH	  (BST_BUTTON_ICON_WIDTH)
-#define BST_DRAG_ICON_HEIGHT	  (BST_BUTTON_ICON_HEIGHT)
-#define BST_TOOLBAR_ICON_WIDTH    (BST_BUTTON_ICON_WIDTH)
-#define BST_TOOLBAR_ICON_HEIGHT   (BST_BUTTON_ICON_WIDTH)
-#define BST_PALETTE_ICON_WIDTH    (BST_TOOLBAR_ICON_WIDTH)
-#define BST_PALETTE_ICON_HEIGHT   (BST_TOOLBAR_ICON_HEIGHT)
+
+/* --- configuration candidates --- */
+/* mouse button numbers and masks for drag operations */
 #define BST_DRAG_BUTTON_COPY	  (1)
 #define BST_DRAG_BUTTON_COPY_MASK (GDK_BUTTON1_MASK)
 #define BST_DRAG_BUTTON_MOVE	  (2)
@@ -111,44 +116,30 @@ typedef enum
 #define BST_DRAG_BUTTON_CONTEXT   (3) /* delete, clone, linkdup */
 
 
-/* --- GUI padding --- */
-#define	BST_OUTER_PADDING	  (2)
-#define	BST_INNER_PADDING	  (3)
-
-
-/* --- debug stuff --- */
-typedef enum                    /*< skip >*/
-{ /* keep in sync with bstmain.c */
-  BST_DEBUG_KEYTABLE		= (1 << 0),
-  BST_DEBUG_SAMPLES		= (1 << 1)
-} BstDebugFlags;
-extern BstDebugFlags bst_debug_flags;
-#ifdef G_ENABLE_DEBUG
-#  define BST_IF_DEBUG(type)	if (!(bst_debug_flags & BST_DEBUG_ ## type)) { } else
-#else  /* !G_ENABLE_DEBUG */
-#  define BST_IF_DEBUG(type)	while (0) /* don't exec */
-#endif /* !G_ENABLE_DEBUG */
-#define	BST_DVL_EXT		(BSE_DVL_EXT)
-#define	BST_DVL_HINTS		(bst_dvl_hints)
-extern gboolean bst_dvl_hints;
-
-extern void bst_update_can_operate (GtkWidget   *some_widget);
-
+/* --- miscellaneous --- */
+#define	BST_DVL_HINTS		(bst_developer_hints != FALSE)
+#define	BST_DVL_EXT		(bst_developer_extensions != FALSE)
+#define	BST_MAIN_LOOP_QUIT()	do { bst_main_loop_running = FALSE; } while (0)
 #define	GNOME_CANVAS_NOTIFY(object)	G_STMT_START { \
     if (GTK_IS_OBJECT (object)) \
       g_signal_emit_by_name (object, "notify::generic-change", NULL); \
 } G_STMT_END
-
-#define bst_nullify_on_destroy(obj, location) \
-  g_signal_connect_swapped ((obj), "destroy", G_CALLBACK (g_nullify_pointer), (location))
-
-#define	BST_TOOLTIPS	(bst_global_tooltips ())
+extern void bst_update_can_operate (GtkWidget   *some_widget);
 
 
+/* --- i18n and gettext helpers --- */
+#define CKEY(x) x
+/* allow gettext-ization */
+#define	_N(x)	x
+#define	_(x)	x
 
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+/* --- internal stuff --- */
+extern gboolean bst_developer_hints;
+extern gboolean bst_developer_extensions;
+extern gboolean bst_main_loop_running;
+
+
+G_END_DECLS
 
 #endif /* __BST_DEFS_H__ */
