@@ -2,60 +2,15 @@
 /* Generated data (by glib-mkenums) */
 
 
-/* --- bstdefs.h --- */
-#include	"bstdefs.h"
-/* BstOps
+/* --- bstmarker.h --- */
+#include	"bstmarker.h"
+/* BstMarkerType
  */
-static GEnumValue bst_ops_values[] = {
-  { BST_OP_NONE, "BST_OP_NONE", "none" },
-  { BST_OP_PROJECT_NEW, "BST_OP_PROJECT_NEW", "project-new" },
-  { BST_OP_PROJECT_OPEN, "BST_OP_PROJECT_OPEN", "project-open" },
-  { BST_OP_PROJECT_SAVE, "BST_OP_PROJECT_SAVE", "project-save" },
-  { BST_OP_PROJECT_SAVE_AS, "BST_OP_PROJECT_SAVE_AS", "project-save-as" },
-  { BST_OP_PROJECT_NEW_SONG, "BST_OP_PROJECT_NEW_SONG", "project-new-song" },
-  { BST_OP_PROJECT_NEW_SNET, "BST_OP_PROJECT_NEW_SNET", "project-new-snet" },
-  { BST_OP_PROJECT_NEW_MIDI_SYNTH, "BST_OP_PROJECT_NEW_MIDI_SYNTH", "project-new-midi-synth" },
-  { BST_OP_PROJECT_CLOSE, "BST_OP_PROJECT_CLOSE", "project-close" },
-  { BST_OP_PROJECT_PLAY, "BST_OP_PROJECT_PLAY", "project-play" },
-  { BST_OP_PROJECT_STOP, "BST_OP_PROJECT_STOP", "project-stop" },
-  { BST_OP_PROJECT_RACK_EDITOR, "BST_OP_PROJECT_RACK_EDITOR", "project-rack-editor" },
-  { BST_OP_DIALOG_PREFERENCES, "BST_OP_DIALOG_PREFERENCES", "dialog-preferences" },
-  { BST_OP_DIALOG_PROC_BROWSER, "BST_OP_DIALOG_PROC_BROWSER", "dialog-proc-browser" },
-  { BST_OP_DIALOG_DEVICE_MONITOR, "BST_OP_DIALOG_DEVICE_MONITOR", "dialog-device-monitor" },
-  { BST_OP_REBUILD, "BST_OP_REBUILD", "rebuild" },
-  { BST_OP_REFRESH, "BST_OP_REFRESH", "refresh" },
-  { BST_OP_PART_ADD, "BST_OP_PART_ADD", "part-add" },
-  { BST_OP_PART_DELETE, "BST_OP_PART_DELETE", "part-delete" },
-  { BST_OP_PART_EDITOR, "BST_OP_PART_EDITOR", "part-editor" },
-  { BST_OP_WAVE_LOAD, "BST_OP_WAVE_LOAD", "wave-load" },
-  { BST_OP_WAVE_DELETE, "BST_OP_WAVE_DELETE", "wave-delete" },
-  { BST_OP_WAVE_EDITOR, "BST_OP_WAVE_EDITOR", "wave-editor" },
-  { BST_OP_TRACK_ADD, "BST_OP_TRACK_ADD", "track-add" },
-  { BST_OP_TRACK_DELETE, "BST_OP_TRACK_DELETE", "track-delete" },
-  { BST_OP_UNDO_LAST, "BST_OP_UNDO_LAST", "undo-last" },
-  { BST_OP_REDO_LAST, "BST_OP_REDO_LAST", "redo-last" },
-  { BST_OP_EXIT, "BST_OP_EXIT", "exit" },
-  { BST_OP_HELP_FAQ, "BST_OP_HELP_FAQ", "help-faq" },
-  { BST_OP_HELP_KEYTABLE, "BST_OP_HELP_KEYTABLE", "help-keytable" },
-  { BST_OP_HELP_RELEASE_NOTES, "BST_OP_HELP_RELEASE_NOTES", "help-release-notes" },
-  { BST_OP_HELP_GSL_PLAN, "BST_OP_HELP_GSL_PLAN", "help-gsl-plan" },
-  { BST_OP_HELP_QUICK_START, "BST_OP_HELP_QUICK_START", "help-quick-start" },
-  { BST_OP_HELP_ABOUT, "BST_OP_HELP_ABOUT", "help-about" },
-  { BST_OP_LAST, "BST_OP_LAST", "last" },
-  { 0, NULL, NULL }
-};
-
-
-/* --- bstdialog.h --- */
-#include	"bstdialog.h"
-/* BstDialogFlags
- */
-static GFlagsValue bst_dialog_flags_values[] = {
-  { BST_DIALOG_HIDE_ON_DELETE, "BST_DIALOG_HIDE_ON_DELETE", "hide-on-delete" },
-  { BST_DIALOG_STATUS_SHELL, "BST_DIALOG_STATUS_SHELL", "status-shell" },
-  { BST_DIALOG_MODAL, "BST_DIALOG_MODAL", "modal" },
-  { BST_DIALOG_POPUP_POS, "BST_DIALOG_POPUP_POS", "popup-pos" },
-  { BST_DIALOG_DELETE_BUTTON, "BST_DIALOG_DELETE_BUTTON", "delete-button" },
+static GEnumValue bst_marker_type_values[] = {
+  { BST_MARKER_NONE, "BST_MARKER_NONE", "none" },
+  { BST_MARKER_RED, "BST_MARKER_RED", "red" },
+  { BST_MARKER_GREEN, "BST_MARKER_GREEN", "green" },
+  { BST_MARKER_BLUE, "BST_MARKER_BLUE", "blue" },
   { 0, NULL, NULL }
 };
 
@@ -78,22 +33,6 @@ static GFlagsValue bst_choice_flags_values[] = {
 };
 
 
-/* --- bstpianorollctrl.h --- */
-#include	"bstpianorollctrl.h"
-/* BstPianoRollTool
- */
-static GEnumValue bst_piano_roll_tool_values[] = {
-  { BST_PIANO_ROLL_TOOL_NONE, "BST_PIANO_ROLL_TOOL_NONE", "none" },
-  { BST_PIANO_ROLL_TOOL_INSERT, "BST_PIANO_ROLL_TOOL_INSERT", "insert" },
-  { BST_PIANO_ROLL_TOOL_RESIZE, "BST_PIANO_ROLL_TOOL_RESIZE", "resize" },
-  { BST_PIANO_ROLL_TOOL_MOVE, "BST_PIANO_ROLL_TOOL_MOVE", "move" },
-  { BST_PIANO_ROLL_TOOL_DELETE, "BST_PIANO_ROLL_TOOL_DELETE", "delete" },
-  { BST_PIANO_ROLL_TOOL_SELECT, "BST_PIANO_ROLL_TOOL_SELECT", "select" },
-  { BST_PIANO_ROLL_TOOL_VSELECT, "BST_PIANO_ROLL_TOOL_VSELECT", "vselect" },
-  { 0, NULL, NULL }
-};
-
-
 /* --- bstqsampler.h --- */
 #include	"bstqsampler.h"
 /* BstQSamplerType
@@ -129,33 +68,72 @@ static GEnumValue bst_qsampler_draw_mode_values[] = {
 
 /* --- bstradiotools.h --- */
 #include	"bstradiotools.h"
-/* BstRadioToolFlags
+/* BstRadioToolsFlags
  */
-static GFlagsValue bst_radio_tool_flags_values[] = {
+static GFlagsValue bst_radio_tools_flags_values[] = {
+  { BST_RADIO_TOOLS_NONE, "BST_RADIO_TOOLS_NONE", "none" },
   { BST_RADIO_TOOLS_TOOLBAR, "BST_RADIO_TOOLS_TOOLBAR", "toolbar" },
   { BST_RADIO_TOOLS_PALETTE, "BST_RADIO_TOOLS_PALETTE", "palette" },
-  { BST_RADIO_TOOLS_CHOICE, "BST_RADIO_TOOLS_CHOICE", "choice" },
-  { BST_RADIO_TOOLS_EVERYWHERE, "BST_RADIO_TOOLS_EVERYWHERE", "everywhere" },
   { 0, NULL, NULL }
 };
 
 
-/* --- bsttoolbar.h --- */
-#include	"bsttoolbar.h"
-/* BstToolbarChild
+/* --- bstdefs.h --- */
+#include	"bstdefs.h"
+/* BstOps
  */
-static GEnumValue bst_toolbar_child_values[] = {
-  { BST_TOOLBAR_SPACE, "BST_TOOLBAR_SPACE", "space" },
-  { BST_TOOLBAR_SEPARATOR, "BST_TOOLBAR_SEPARATOR", "separator" },
-  { BST_TOOLBAR_BUTTON, "BST_TOOLBAR_BUTTON", "button" },
-  { BST_TOOLBAR_TRUNC_BUTTON, "BST_TOOLBAR_TRUNC_BUTTON", "trunc-button" },
-  { BST_TOOLBAR_EXTRA_BUTTON, "BST_TOOLBAR_EXTRA_BUTTON", "extra-button" },
-  { BST_TOOLBAR_TOGGLE, "BST_TOOLBAR_TOGGLE", "toggle" },
-  { BST_TOOLBAR_TRUNC_TOGGLE, "BST_TOOLBAR_TRUNC_TOGGLE", "trunc-toggle" },
-  { BST_TOOLBAR_EXTRA_TOGGLE, "BST_TOOLBAR_EXTRA_TOGGLE", "extra-toggle" },
-  { BST_TOOLBAR_WIDGET, "BST_TOOLBAR_WIDGET", "widget" },
-  { BST_TOOLBAR_TRUNC_WIDGET, "BST_TOOLBAR_TRUNC_WIDGET", "trunc-widget" },
-  { BST_TOOLBAR_EXTRA_WIDGET, "BST_TOOLBAR_EXTRA_WIDGET", "extra-widget" },
+static GEnumValue bst_ops_values[] = {
+  { BST_OP_NONE, "BST_OP_NONE", "none" },
+  { BST_OP_PROJECT_NEW, "BST_OP_PROJECT_NEW", "project-new" },
+  { BST_OP_PROJECT_OPEN, "BST_OP_PROJECT_OPEN", "project-open" },
+  { BST_OP_PROJECT_MERGE, "BST_OP_PROJECT_MERGE", "project-merge" },
+  { BST_OP_PROJECT_SAVE, "BST_OP_PROJECT_SAVE", "project-save" },
+  { BST_OP_PROJECT_SAVE_AS, "BST_OP_PROJECT_SAVE_AS", "project-save-as" },
+  { BST_OP_PROJECT_NEW_SONG, "BST_OP_PROJECT_NEW_SONG", "project-new-song" },
+  { BST_OP_PROJECT_NEW_SNET, "BST_OP_PROJECT_NEW_SNET", "project-new-snet" },
+  { BST_OP_PROJECT_NEW_MIDI_SYNTH, "BST_OP_PROJECT_NEW_MIDI_SYNTH", "project-new-midi-synth" },
+  { BST_OP_PROJECT_CLOSE, "BST_OP_PROJECT_CLOSE", "project-close" },
+  { BST_OP_PROJECT_PLAY, "BST_OP_PROJECT_PLAY", "project-play" },
+  { BST_OP_PROJECT_STOP, "BST_OP_PROJECT_STOP", "project-stop" },
+  { BST_OP_PROJECT_RACK_EDITOR, "BST_OP_PROJECT_RACK_EDITOR", "project-rack-editor" },
+  { BST_OP_DIALOG_PREFERENCES, "BST_OP_DIALOG_PREFERENCES", "dialog-preferences" },
+  { BST_OP_DIALOG_PROC_BROWSER, "BST_OP_DIALOG_PROC_BROWSER", "dialog-proc-browser" },
+  { BST_OP_DIALOG_DEVICE_MONITOR, "BST_OP_DIALOG_DEVICE_MONITOR", "dialog-device-monitor" },
+  { BST_OP_REBUILD, "BST_OP_REBUILD", "rebuild" },
+  { BST_OP_PART_ADD, "BST_OP_PART_ADD", "part-add" },
+  { BST_OP_PART_DELETE, "BST_OP_PART_DELETE", "part-delete" },
+  { BST_OP_PART_EDITOR, "BST_OP_PART_EDITOR", "part-editor" },
+  { BST_OP_WAVE_LOAD, "BST_OP_WAVE_LOAD", "wave-load" },
+  { BST_OP_WAVE_DELETE, "BST_OP_WAVE_DELETE", "wave-delete" },
+  { BST_OP_WAVE_EDITOR, "BST_OP_WAVE_EDITOR", "wave-editor" },
+  { BST_OP_TRACK_ADD, "BST_OP_TRACK_ADD", "track-add" },
+  { BST_OP_TRACK_DELETE, "BST_OP_TRACK_DELETE", "track-delete" },
+  { BST_OP_UNDO_LAST, "BST_OP_UNDO_LAST", "undo-last" },
+  { BST_OP_REDO_LAST, "BST_OP_REDO_LAST", "redo-last" },
+  { BST_OP_EXIT, "BST_OP_EXIT", "exit" },
+  { BST_OP_HELP_FAQ, "BST_OP_HELP_FAQ", "help-faq" },
+  { BST_OP_HELP_KEYTABLE, "BST_OP_HELP_KEYTABLE", "help-keytable" },
+  { BST_OP_HELP_RELEASE_NOTES, "BST_OP_HELP_RELEASE_NOTES", "help-release-notes" },
+  { BST_OP_HELP_GSL_PLAN, "BST_OP_HELP_GSL_PLAN", "help-gsl-plan" },
+  { BST_OP_HELP_QUICK_START, "BST_OP_HELP_QUICK_START", "help-quick-start" },
+  { BST_OP_HELP_ABOUT, "BST_OP_HELP_ABOUT", "help-about" },
+  { BST_OP_LAST, "BST_OP_LAST", "last" },
+  { 0, NULL, NULL }
+};
+
+/* BstQuantizationType
+ */
+static GEnumValue bst_quantization_type_values[] = {
+  { BST_QUANTIZE_NONE, "BST_QUANTIZE_NONE", "none" },
+  { BST_QUANTIZE_NOTE_1, "BST_QUANTIZE_NOTE_1", "note-1" },
+  { BST_QUANTIZE_NOTE_2, "BST_QUANTIZE_NOTE_2", "note-2" },
+  { BST_QUANTIZE_NOTE_4, "BST_QUANTIZE_NOTE_4", "note-4" },
+  { BST_QUANTIZE_NOTE_8, "BST_QUANTIZE_NOTE_8", "note-8" },
+  { BST_QUANTIZE_NOTE_16, "BST_QUANTIZE_NOTE_16", "note-16" },
+  { BST_QUANTIZE_NOTE_32, "BST_QUANTIZE_NOTE_32", "note-32" },
+  { BST_QUANTIZE_NOTE_64, "BST_QUANTIZE_NOTE_64", "note-64" },
+  { BST_QUANTIZE_NOTE_128, "BST_QUANTIZE_NOTE_128", "note-128" },
+  { BST_QUANTIZE_TACT, "BST_QUANTIZE_TACT", "tact" },
   { 0, NULL, NULL }
 };
 
