@@ -88,9 +88,9 @@ main (int   argc,
   GSource *source;
   guint i;
 
-  /* nitialize GLib guts */
-  if (toyprof_mem_table && 0)
-    g_mem_set_vtable (toyprof_mem_table);
+  /* initialize GLib guts */
+  if (0)
+    toyprof_init_glib_memtable ("/tmp/beast-leak.debug", 10 /* SIGUSR1 */);
   g_thread_init (NULL);
   g_type_init ();
 
@@ -497,6 +497,8 @@ bst_early_parse_args (int    *argc_p,
 	    g_print ("%s\n", BST_PATH_IMAGES);
 	  else if (strcmp (arg, "plugins") == 0)
 	    g_print ("%s\n", BSE_PATH_PLUGINS);
+	  else if (strcmp (arg, "ladspa") == 0)
+	    g_print ("%s\n", BSE_PATH_LADSPA);
 	  else if (strcmp (arg, "scripts") == 0)
 	    g_print ("%s\n", BSE_PATH_SCRIPTS);
 	  else if (strcmp (arg, "samples") == 0)
@@ -552,6 +554,7 @@ bst_print_blurb (gboolean print_help)
       g_print ("Plugin Path: %s\n", BSE_PATH_PLUGINS);
       g_print ("Script Path: %s\n", BSE_PATH_SCRIPTS);
       g_print ("Sample Path: %s\n", BST_PATH_DATA_SAMPLES);
+      g_print ("LADSPA Path: %s:$LADSPA_PATH\n", BSE_PATH_LADSPA);
       g_print ("\n");
       g_print ("BEAST comes with ABSOLUTELY NO WARRANTY.\n");
       g_print ("You may redistribute copies of BEAST under the terms of\n");
