@@ -19,8 +19,8 @@
 
 
 enum {
-  ARG_0,
-  ARG_SUPER
+  PROP_0,
+  PROP_SUPER
 };
 
 
@@ -29,16 +29,18 @@ static void	bst_super_shell_class_init	(BstSuperShellClass	*klass);
 static void	bst_super_shell_init		(BstSuperShell		*super_shell);
 static void	bst_super_shell_destroy		(GtkObject		*object);
 static void	bst_super_shell_finalize	(GObject		*object);
-static void	bst_super_shell_set_arg		(GtkObject		*object,
-						 GtkArg			*arg,
-						 guint		         arg_id);
-static void	bst_super_shell_get_arg		(GtkObject		*object,
-						 GtkArg			*arg,
-						 guint		         arg_id);
+static void	bst_super_shell_set_property	(GObject         	*object,
+						 guint           	 prop_id,
+						 const GValue    	*value,
+						 GParamSpec      	*pspec);
+static void	bst_super_shell_get_property	(GObject         	*object,
+						 guint           	 prop_id,
+						 GValue          	*value,
+						 GParamSpec      	*pspec);
 static void	bst_super_shell_setup_super	(BstSuperShell		*super_shell,
-						 BswProxy     		 super);
+						 SfiProxy     		 super);
 static void	bst_super_shell_release_super	(BstSuperShell		*super_shell,
-						 BswProxy		 super);
+						 SfiProxy		 super);
 
 
 /* --- static variables --- */
@@ -84,9 +86,10 @@ bst_super_shell_class_init (BstSuperShellClass *class)
 
   quark_super_shell = g_quark_from_static_string ("BstSuperShell");
 
+  gobject_class->set_property = bst_super_shell_set_property;
+  gobject_class->get_property = bst_super_shell_get_property;
   gobject_class->finalize = bst_super_shell_finalize;
-  object_class->set_arg = bst_super_shell_set_arg;
-  object_class->get_arg = bst_super_shell_get_arg;
+
   object_class->destroy = bst_super_shell_destroy;
 
   class->setup_super = bst_super_shell_setup_super;
@@ -94,9 +97,10 @@ bst_super_shell_class_init (BstSuperShellClass *class)
   class->operate = NULL;
   class->can_operate = NULL;
   class->rebuild = NULL;
-  class->update = NULL;
 
-  gtk_object_add_arg_type ("BstSuperShell::super", GTK_TYPE_UINT, GTK_ARG_READWRITE | GTK_ARG_CONSTRUCT, ARG_SUPER);
+  g_object_class_install_property (gobject_class,
+				   PROP_SUPER,
+				   sfi_pspec_proxy ("super", NULL, NULL, SFI_PARAM_DEFAULT));
 }
 
 static void
@@ -104,7 +108,6 @@ bst_super_shell_init (BstSuperShell *super_shell)
 {
   super_shell->accel_group = gtk_accel_group_new ();
   super_shell->super = 0;
-  super_shell->name_set_id = 0;
   
   gtk_widget_set (GTK_WIDGET (super_shell),
 		  "homogeneous", FALSE,
@@ -113,6 +116,44 @@ bst_super_shell_init (BstSuperShell *super_shell)
 		  NULL);
 }
 
+static void
+bst_super_shell_set_property (GObject         *object,
+			      guint            prop_id,
+			      const GValue    *value,
+			      GParamSpec      *pspec)
+{
+  BstSuperShell *super_shell = BST_SUPER_SHELL (object);
+
+  switch (prop_id)
+    {
+    case PROP_SUPER:
+      bst_super_shell_set_super (super_shell, sfi_value_get_proxy (value));
+      break;
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
+    }
+}
+
+static void
+bst_super_shell_get_property (GObject         *object,
+			      guint            prop_id,
+			      GValue          *value,
+			      GParamSpec      *pspec)
+{
+  BstSuperShell *super_shell = BST_SUPER_SHELL (object);
+
+  switch (prop_id)
+    {
+    case PROP_SUPER:
+      sfi_value_set_proxy (value, super_shell->super);
+      break;
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
+    }
+}
+
 static void
 bst_super_shell_destroy (GtkObject *object)
 {
@@ -120,7 +161,7 @@ bst_super_shell_destroy (GtkObject *object)
 
   if (super_shell->super)
     {
-      bsw_source_clear_outputs (super_shell->super);
+      bse_source_clear_outputs (super_shell->super);
       bst_super_shell_set_super (super_shell, 0);
     }
   
@@ -138,58 +179,19 @@ bst_super_shell_finalize (GObject *object)
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
-static void
-bst_super_shell_set_arg (GtkObject *object,
-			 GtkArg    *arg,
-			 guint      arg_id)
-{
-  BstSuperShell *super_shell;
-
-  super_shell = BST_SUPER_SHELL (object);
-
-  switch (arg_id)
-    {
-    case ARG_SUPER:
-      bst_super_shell_set_super (super_shell, GTK_VALUE_UINT (*arg));
-      break;
-    default:
-      break;
-    }
-}
-
-static void
-bst_super_shell_get_arg (GtkObject *object,
-			 GtkArg    *arg,
-			 guint      arg_id)
-{
-  BstSuperShell *super_shell;
-
-  super_shell = BST_SUPER_SHELL (object);
-
-  switch (arg_id)
-    {
-    case ARG_SUPER:
-      GTK_VALUE_UINT (*arg) = super_shell->super;
-      break;
-    default:
-      arg->type = GTK_TYPE_INVALID;
-      break;
-    }
-}
-
 static void
 bst_super_shell_name_set (BstSuperShell *super_shell,
 			  GParamSpec	*pspec,
-			  BseSuper	*super)
+			  SfiProxy	 super)
 {
   GtkWidget *widget;
 
   widget = GTK_WIDGET (super_shell);
   if (widget->parent && GTK_IS_NOTEBOOK (widget->parent))
     {
-      gchar *name = g_strconcat (BSE_OBJECT_TYPE_NAME (super),
+      gchar *name = g_strconcat (bse_item_get_type (super),
 				 ":\n",
-				 bsw_item_get_name (BSE_OBJECT_ID (super)),
+				 bse_item_get_name (super),
 				 NULL);
       
       widget = gtk_notebook_get_tab_label (GTK_NOTEBOOK (widget->parent), widget);
@@ -204,33 +206,34 @@ bst_super_shell_name_set (BstSuperShell *super_shell,
 
 static void
 bst_super_shell_setup_super (BstSuperShell *super_shell,
-			     BswProxy       super)
+			     SfiProxy       super)
 {
-  bse_object_set_qdata (bse_object_from_id (super), quark_super_shell, super_shell);
-  super_shell->name_set_id = g_signal_connect_data (bse_object_from_id (super), "notify::uname",
-						    G_CALLBACK (bst_super_shell_name_set), super_shell, NULL,
-						    G_CONNECT_SWAPPED);
+  bse_proxy_set_qdata (super, quark_super_shell, super_shell);	// FIXME: need to support a list of shells here
+  bse_proxy_connect (super,
+		     "swapped_signal::property-notify::uname", bst_super_shell_name_set, super_shell,
+		     NULL);
   BST_SUPER_SHELL_GET_CLASS (super_shell)->rebuild (super_shell);
 }
 
 static void
 bst_super_shell_release_super (BstSuperShell *super_shell,
-			       BswProxy       super)
+			       SfiProxy       super)
 {
-  g_signal_handler_disconnect (bse_object_from_id (super), super_shell->name_set_id);
-  super_shell->name_set_id = 0;
-  bse_object_set_qdata (bse_object_from_id (super), quark_super_shell, NULL);
+  bse_proxy_disconnect (super,
+			"any_signal::property-notify::uname", bst_super_shell_name_set, super_shell,
+			NULL);
+  bse_proxy_set_qdata (super, quark_super_shell, NULL);
   gtk_container_foreach (GTK_CONTAINER (super_shell), (GtkCallback) gtk_widget_destroy, NULL);
 }
 
 void
 bst_super_shell_set_super (BstSuperShell *super_shell,
-			   BswProxy       super)
+			   SfiProxy       super)
 {
   g_return_if_fail (BST_IS_SUPER_SHELL (super_shell));
   if (super)
     {
-      g_return_if_fail (BSW_IS_SUPER (super));
+      g_return_if_fail (BSE_IS_SUPER (super));
       g_return_if_fail (bst_super_shell_from_super (super) == 0);
     }
   
@@ -239,45 +242,34 @@ bst_super_shell_set_super (BstSuperShell *super_shell,
       if (super_shell->super)
 	{
 	  BST_SUPER_SHELL_GET_CLASS (super_shell)->release_super (super_shell, super_shell->super);
-	  bsw_item_unuse (super_shell->super);
+	  bse_item_unuse (super_shell->super);
 	}
       super_shell->super = super;
       if (super_shell->super)
 	{
-	  bsw_item_use (super_shell->super);
+	  bse_item_use (super_shell->super);
 	  BST_SUPER_SHELL_GET_CLASS (super_shell)->setup_super (super_shell, super_shell->super);
-	  bst_super_shell_name_set (super_shell, NULL, bse_object_from_id (super));
+	  bst_super_shell_name_set (super_shell, NULL, super);
 	}
     }
 }
 
 void
-bst_super_shell_update (BstSuperShell *super_shell)
+bst_super_shell_update_label (BstSuperShell *super_shell)
 {
   g_return_if_fail (BST_IS_SUPER_SHELL (super_shell));
 
-  bst_super_shell_name_set (super_shell, NULL, bse_object_from_id (super_shell->super));
-      
-  if (BST_SUPER_SHELL_GET_CLASS (super_shell)->update)
-    BST_SUPER_SHELL_GET_CLASS (super_shell)->update (super_shell);
-}
-
-void
-bst_super_shell_update_parent (BstSuperShell *super_shell)
-{
-  g_return_if_fail (BST_IS_SUPER_SHELL (super_shell));
-
-  bst_super_shell_name_set (super_shell, NULL, bse_object_from_id (super_shell->super));
+  bst_super_shell_name_set (super_shell, NULL, super_shell->super);
 }
 
 BstSuperShell*
-bst_super_shell_from_super (BswProxy super)
+bst_super_shell_from_super (SfiProxy super)
 {
   BstSuperShell *super_shell;
 
-  g_return_val_if_fail (BSW_IS_SUPER (super), NULL);
+  g_return_val_if_fail (BSE_IS_SUPER (super), NULL);
 
-  super_shell = bse_object_get_qdata (bse_object_from_id (super), quark_super_shell);
+  super_shell = bse_proxy_get_qdata (super, quark_super_shell);
   if (super_shell)
     g_return_val_if_fail (BST_IS_SUPER_SHELL (super_shell), NULL);
 
