@@ -2,6 +2,8 @@
 /* Generated data (by glib-mkenums) */
 
 
+GType BSE_TYPE_ID (BseFileHandlerType) = 0;
+
 GType BSE_TYPE_ID (BseBinDataType) = 0;
 
 GType BSE_TYPE_ID (BseBiquadFilterType) = 0;
@@ -22,8 +24,6 @@ GType BSE_TYPE_ID (BseUserMsgType) = 0;
 
 GType BSE_TYPE_ID (BseErrorType) = 0;
 
-GType BSE_TYPE_ID (BseFileHandlerType) = 0;
-
 GType BSE_TYPE_ID (BseTimeRangeType) = 0;
 
 GType BSE_TYPE_ID (BseMidiEventType) = 0;
@@ -135,6 +135,10 @@ GType bse_type_builtin_id_BsePcmDeviceOSS = 0;
 extern BSE_BUILTIN_PROTO (BsePlugin);
 GType bse_type_builtin_id_BsePlugin = 0;
 
+/* --- bseladspa.c --- */
+extern BSE_BUILTIN_PROTO (BseLadspaPlugin);
+GType bse_type_builtin_id_BseLadspaPlugin = 0;
+
 /* --- bseproject.c --- */
 extern BSE_BUILTIN_PROTO (BseProject);
 GType bse_type_builtin_id_BseProject = 0;
@@ -215,6 +219,10 @@ GType bse_type_builtin_id_BseWaveOsc = 0;
 extern BSE_BUILTIN_PROTO (BseWaveRepo);
 GType bse_type_builtin_id_BseWaveRepo = 0;
 
+/* --- bseladspamodule.c --- */
+extern BSE_BUILTIN_PROTO (BseLadspaModule);
+GType bse_type_builtin_id_BseLadspaModule = 0;
+
 /**
  ** Generated data ends here
  **/
