@@ -23,7 +23,6 @@
 #include        "bsesubsynth.h"
 #include        "bsepcmoutput.h"
 #include        "bseproject.h"
-#include        "bswprivate.h"
 #include        <string.h>
 #include        <time.h>
 #include        <fcntl.h>
@@ -49,7 +48,7 @@ enum
 /* --- prototypes --- */
 static void	bse_midi_synth_class_init	 (BseMidiSynthClass	*class);
 static void	bse_midi_synth_init		 (BseMidiSynth		*msynth);
-static void	bse_midi_synth_destroy		 (BseObject		*object);
+static void	bse_midi_synth_finalize		 (GObject		*object);
 static void	bse_midi_synth_set_property	 (GObject		*object,
 						  guint			 param_id,
 						  const GValue		*value,
@@ -58,7 +57,7 @@ static void	bse_midi_synth_get_property	 (GObject		*msynth,
 						  guint			 param_id,
 						  GValue		*value,
 						  GParamSpec		*pspec);
-static BswIterProxy* bse_midi_synth_list_proxies (BseItem		*item,
+static BseProxySeq* bse_midi_synth_list_proxies  (BseItem		*item,
 						  guint			 param_id,
 						  GParamSpec		*pspec);
 static void	bse_midi_synth_context_create	 (BseSource		*source,
@@ -74,7 +73,7 @@ static GTypeClass     *parent_class = NULL;
 BSE_BUILTIN_TYPE (BseMidiSynth)
 {
   GType midi_synth_type;
-
+  
   static const GTypeInfo snet_info = {
     sizeof (BseMidiSynthClass),
     
@@ -93,7 +92,7 @@ BSE_BUILTIN_TYPE (BseMidiSynth)
 					      "BseMidiSynth",
 					      "BSE Midi Synthesizer",
 					      &snet_info);
-
+  
   return midi_synth_type;
 }
 
@@ -109,78 +108,74 @@ bse_midi_synth_class_init (BseMidiSynthClass *class)
   
   gobject_class->set_property = bse_midi_synth_set_property;
   gobject_class->get_property = bse_midi_synth_get_property;
-
-  object_class->destroy = bse_midi_synth_destroy;
-
+  gobject_class->finalize = bse_midi_synth_finalize;
+  
   item_class->list_proxies = bse_midi_synth_list_proxies;
-
+  
   source_class->context_create = bse_midi_synth_context_create;
   
   bse_object_class_add_param (object_class, "MIDI Instrument",
 			      PARAM_MIDI_CHANNEL,
-			      bse_param_spec_uint ("midi_channel", "MIDI Channel", NULL,
-						   1, BSE_MIDI_MAX_CHANNELS,
-						   1, 1,
-						   BSE_PARAM_GUI | BSE_PARAM_STORAGE | BSE_PARAM_HINT_SCALE));
+			      sfi_pspec_int ("midi_channel", "MIDI Channel", NULL,
+					     1, 1, BSE_MIDI_MAX_CHANNELS, 1,
+					     SFI_PARAM_GUI SFI_PARAM_STORAGE SFI_PARAM_HINT_SCALE));
   bse_object_class_add_param (object_class, "MIDI Instrument",
 			      PARAM_N_VOICES,
-			      bse_param_spec_uint ("n_voices", "Max Voixes", "Maximum number of voices for simultaneous playback",
-						   1, 256,
-						   1, 1,
-						   BSE_PARAM_GUI | BSE_PARAM_STORAGE | BSE_PARAM_HINT_SCALE));
+			      sfi_pspec_int ("n_voices", "Max Voixes", "Maximum number of voices for simultaneous playback",
+					     1, 1, 256, 1,
+					     SFI_PARAM_GUI SFI_PARAM_STORAGE SFI_PARAM_HINT_SCALE));
   bse_object_class_add_param (object_class, "MIDI Instrument",
 			      PARAM_SNET,
-			      g_param_spec_object ("snet", "Synthesis Network", "The MIDI instrument synthesis network",
-						   BSE_TYPE_SNET, BSE_PARAM_DEFAULT));
+			      bse_param_spec_object ("snet", "Synthesis Network", "The MIDI instrument synthesis network",
+						     BSE_TYPE_SNET, SFI_PARAM_DEFAULT));
   bse_object_class_add_param (object_class, "Adjustments",
 			      PARAM_VOLUME_f,
-			      bse_param_spec_float ("volume_f", "Master [float]", NULL,
-						    0, bse_dB_to_factor (BSE_MAX_VOLUME_dB),
-						    bse_dB_to_factor (BSE_DFL_MASTER_VOLUME_dB), 0.1,
-						    BSE_PARAM_STORAGE));
+			      sfi_pspec_real ("volume_f", "Master [float]", NULL,
+					      bse_dB_to_factor (BSE_DFL_MASTER_VOLUME_dB),
+					      0, bse_dB_to_factor (BSE_MAX_VOLUME_dB), 0.1,
+					      SFI_PARAM_STORAGE));
   bse_object_class_add_param (object_class, "Adjustments",
 			      PARAM_VOLUME_dB,
-			      bse_param_spec_float ("volume_dB", "Master [dB]", NULL,
-						    BSE_MIN_VOLUME_dB, BSE_MAX_VOLUME_dB,
-						    BSE_DFL_MASTER_VOLUME_dB, BSE_STP_VOLUME_dB,
-						    BSE_PARAM_GUI |
-						    BSE_PARAM_HINT_DIAL));
+			      sfi_pspec_real ("volume_dB", "Master [dB]", NULL,
+					      BSE_DFL_MASTER_VOLUME_dB,
+					      BSE_MIN_VOLUME_dB, BSE_MAX_VOLUME_dB,
+					      BSE_GCONFIG (step_volume_dB),
+					      SFI_PARAM_GUI SFI_PARAM_HINT_DIAL));
   bse_object_class_add_param (object_class, "Adjustments",
 			      PARAM_VOLUME_PERC,
-			      bse_param_spec_uint ("volume_perc", "Master [%]", NULL,
-						   0, bse_dB_to_factor (BSE_MAX_VOLUME_dB) * 100,
-						   bse_dB_to_factor (BSE_DFL_MASTER_VOLUME_dB) * 100, 1,
-						   BSE_PARAM_GUI |
-						   BSE_PARAM_HINT_DIAL));
+			      sfi_pspec_int ("volume_perc", "Master [%]", NULL,
+					     bse_dB_to_factor (BSE_DFL_MASTER_VOLUME_dB) * 100,
+					     0, bse_dB_to_factor (BSE_MAX_VOLUME_dB) * 100, 1,
+					     SFI_PARAM_GUI SFI_PARAM_HINT_DIAL));
   bse_object_class_add_param (object_class, "Playback Settings",
 			      PARAM_AUTO_ACTIVATE,
-			      g_param_spec_boolean ("auto_activate", NULL, NULL,
-						    TRUE, /* change default */
-						    /* override parent property */ 0));
+			      sfi_pspec_bool ("auto_activate", NULL, NULL,
+					      TRUE, /* change default */
+					      /* override parent property */ 0));
 }
 
 static void
 bse_midi_synth_init (BseMidiSynth *self)
 {
   BseErrorType error;
-
+  
   BSE_OBJECT_UNSET_FLAGS (self, BSE_SNET_FLAG_USER_SYNTH);
-  BSE_SUPER (self)->auto_activate = TRUE;
+  BSE_OBJECT_SET_FLAGS (self, BSE_SUPER_FLAG_NEEDS_CONTEXT | BSE_SUPER_FLAG_NEEDS_SEQUENCER);
   self->midi_channel_id = 1;
   self->n_voices = 1;
   self->volume_factor = bse_dB_to_factor (BSE_DFL_MASTER_VOLUME_dB);
-
+  
   /* midi voice modules */
   self->voice_input = bse_container_new_item (BSE_CONTAINER (self), BSE_TYPE_MIDI_VOICE_INPUT, NULL);
-  BSE_OBJECT_SET_FLAGS (self->voice_input, BSE_ITEM_FLAG_STORAGE_IGNORE);
+  BSE_OBJECT_SET_FLAGS (self->voice_input, BSE_ITEM_FLAG_AGGREGATE);
   self->voice_switch = bse_container_new_item (BSE_CONTAINER (self), BSE_TYPE_MIDI_VOICE_SWITCH, NULL);
-  BSE_OBJECT_SET_FLAGS (self->voice_switch, BSE_ITEM_FLAG_STORAGE_IGNORE);
+  BSE_OBJECT_SET_FLAGS (self->voice_switch, BSE_ITEM_FLAG_AGGREGATE);
   bse_midi_voice_switch_set_voice_input (BSE_MIDI_VOICE_SWITCH (self->voice_switch), BSE_MIDI_VOICE_INPUT (self->voice_input));
   
   /* context merger */
   self->context_merger = bse_container_new_item (BSE_CONTAINER (self), BSE_TYPE_CONTEXT_MERGER, NULL);
-  BSE_OBJECT_SET_FLAGS (self->context_merger, BSE_ITEM_FLAG_STORAGE_IGNORE);
-
+  BSE_OBJECT_SET_FLAGS (self->context_merger, BSE_ITEM_FLAG_AGGREGATE);
+  
   /* midi voice switch <-> context merger */
   error = bse_source_set_input (self->context_merger, 0,
 				self->voice_switch, BSE_MIDI_VOICE_SWITCH_OCHANNEL_LEFT);
@@ -188,11 +183,11 @@ bse_midi_synth_init (BseMidiSynth *self)
   error = bse_source_set_input (self->context_merger, 1,
 				self->voice_switch, BSE_MIDI_VOICE_SWITCH_OCHANNEL_RIGHT);
   g_assert (error == BSE_ERROR_NONE);
-
+  
   /* output */
   self->output = bse_container_new_item (BSE_CONTAINER (self), BSE_TYPE_PCM_OUTPUT, NULL);
-  BSE_OBJECT_SET_FLAGS (self->output, BSE_ITEM_FLAG_STORAGE_IGNORE);
-
+  BSE_OBJECT_SET_FLAGS (self->output, BSE_ITEM_FLAG_AGGREGATE);
+  
   /* context merger <-> output */
   error = bse_source_set_input (self->output, BSE_PCM_OUTPUT_ICHANNEL_LEFT,
 				self->context_merger, 0);
@@ -200,7 +195,7 @@ bse_midi_synth_init (BseMidiSynth *self)
   error = bse_source_set_input (self->output, BSE_PCM_OUTPUT_ICHANNEL_RIGHT,
 				self->context_merger, 1);
   g_assert (error == BSE_ERROR_NONE);
-
+  
   /* sub synth */
   self->sub_synth = bse_container_new_item (BSE_CONTAINER (self), BSE_TYPE_SUB_SYNTH,
 					    "in_port_1", "frequency",
@@ -212,8 +207,8 @@ bse_midi_synth_init (BseMidiSynth *self)
 					    "out_port_3", "unused",
 					    "out_port_4", "synth-done",
 					    NULL);
-  BSE_OBJECT_SET_FLAGS (self->sub_synth, BSE_ITEM_FLAG_STORAGE_IGNORE);
-
+  BSE_OBJECT_SET_FLAGS (self->sub_synth, BSE_ITEM_FLAG_AGGREGATE);
+  
   /* voice input <-> sub-synth */
   error = bse_source_set_input (self->sub_synth, 0,
 				self->voice_input, BSE_MIDI_VOICE_INPUT_OCHANNEL_FREQUENCY);
@@ -227,7 +222,7 @@ bse_midi_synth_init (BseMidiSynth *self)
   error = bse_source_set_input (self->sub_synth, 3,
 				self->voice_input, BSE_MIDI_VOICE_INPUT_OCHANNEL_AFTERTOUCH);
   g_assert (error == BSE_ERROR_NONE);
-
+  
   /* sub-synth <-> voice switch */
   error = bse_source_set_input (self->voice_switch, BSE_MIDI_VOICE_SWITCH_ICHANNEL_LEFT,
 				self->sub_synth, 0);
@@ -241,10 +236,10 @@ bse_midi_synth_init (BseMidiSynth *self)
 }
 
 static void
-bse_midi_synth_destroy (BseObject *object)
+bse_midi_synth_finalize (GObject *object)
 {
   BseMidiSynth *self = BSE_MIDI_SYNTH (object);
-
+  
   bse_container_remove_item (BSE_CONTAINER (self), BSE_ITEM (self->voice_input));
   self->voice_input = NULL;
   bse_container_remove_item (BSE_CONTAINER (self), BSE_ITEM (self->voice_switch));
@@ -257,7 +252,7 @@ bse_midi_synth_destroy (BseObject *object)
   self->sub_synth = NULL;
   
   /* chain parent class' destroy handler */
-  BSE_OBJECT_CLASS (parent_class)->destroy (object);
+  G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 static gboolean
@@ -273,17 +268,17 @@ check_synth (BseItem *item)
   return G_OBJECT_TYPE (item) == BSE_TYPE_SNET;
 }
 
-static BswIterProxy*
+static BseProxySeq*
 bse_midi_synth_list_proxies (BseItem    *item,
 			     guint       param_id,
 			     GParamSpec *pspec)
 {
   BseMidiSynth *self = BSE_MIDI_SYNTH (item);
-  BswIterProxy *iter = bsw_iter_create (BSW_TYPE_ITER_PROXY, 0);
+  BseProxySeq *pseq = bse_proxy_seq_new ();
   switch (param_id)
     {
     case PARAM_SNET:
-      bse_item_gather_proxies (item, iter, BSE_TYPE_SNET,
+      bse_item_gather_proxies (item, pseq, BSE_TYPE_SNET,
 			       (BseItemCheckContainer) check_project,
 			       (BseItemCheckProxy) check_synth,
 			       NULL);
@@ -292,7 +287,7 @@ bse_midi_synth_list_proxies (BseItem    *item,
       G_OBJECT_WARN_INVALID_PROPERTY_ID (self, param_id, pspec);
       break;
     }
-  return iter;
+  return pseq;
 }
 
 static void
@@ -305,33 +300,33 @@ bse_midi_synth_set_property (GObject      *object,
   switch (param_id)
     {
     case PARAM_SNET:
-      g_object_set (self->sub_synth, "snet", g_value_get_object (value), NULL);
+      g_object_set (self->sub_synth, "snet", bse_value_get_object (value), NULL);
       break;
     case PARAM_MIDI_CHANNEL:
       if (!BSE_SOURCE_PREPARED (self))	/* midi channel is locked while prepared */
-	self->midi_channel_id = g_value_get_uint (value);
+	self->midi_channel_id = sfi_value_get_int (value);
       break;
     case PARAM_N_VOICES:
       if (!BSE_OBJECT_IS_LOCKED (self))
-	self->n_voices = g_value_get_uint (value);
+	self->n_voices = sfi_value_get_int (value);
       break;
     case PARAM_VOLUME_f:
-      self->volume_factor = g_value_get_float (value);
+      self->volume_factor = sfi_value_get_real (value);
       g_object_set (self->output, "master_volume_f", self->volume_factor, NULL);
-      bse_object_param_changed (BSE_OBJECT (self), "volume_dB");
-      bse_object_param_changed (BSE_OBJECT (self), "volume_perc");
+      g_object_notify (self, "volume_dB");
+      g_object_notify (self, "volume_perc");
       break;
     case PARAM_VOLUME_dB:
-      self->volume_factor = bse_dB_to_factor (g_value_get_float (value));
+      self->volume_factor = bse_dB_to_factor (sfi_value_get_real (value));
       g_object_set (self->output, "master_volume_f", self->volume_factor, NULL);
-      bse_object_param_changed (BSE_OBJECT (self), "volume_f");
-      bse_object_param_changed (BSE_OBJECT (self), "volume_perc");
+      g_object_notify (self, "volume_f");
+      g_object_notify (self, "volume_perc");
       break;
     case PARAM_VOLUME_PERC:
-      self->volume_factor = g_value_get_uint (value) / 100.0;
+      self->volume_factor = sfi_value_get_int (value) / 100.0;
       g_object_set (self->output, "master_volume_f", self->volume_factor, NULL);
-      bse_object_param_changed (BSE_OBJECT (self), "volume_f");
-      bse_object_param_changed (BSE_OBJECT (self), "volume_dB");
+      g_object_notify (self, "volume_f");
+      g_object_notify (self, "volume_dB");
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (self, param_id, pspec);
@@ -352,19 +347,19 @@ bse_midi_synth_get_property (GObject    *object,
       g_object_get_property (G_OBJECT (self->sub_synth), "snet", value);
       break;
     case PARAM_MIDI_CHANNEL:
-      g_value_set_uint (value, self->midi_channel_id);
+      sfi_value_set_int (value, self->midi_channel_id);
       break;
     case PARAM_N_VOICES:
-      g_value_set_uint (value, self->n_voices);
+      sfi_value_set_int (value, self->n_voices);
       break;
     case PARAM_VOLUME_f:
-      g_value_set_float (value, self->volume_factor);
+      sfi_value_set_real (value, self->volume_factor);
       break;
     case PARAM_VOLUME_dB:
-      g_value_set_float (value, bse_dB_from_factor (self->volume_factor, BSE_MIN_VOLUME_dB));
+      sfi_value_set_real (value, bse_dB_from_factor (self->volume_factor, BSE_MIN_VOLUME_dB));
       break;
     case PARAM_VOLUME_PERC:
-      g_value_set_uint (value, self->volume_factor * 100.0 + 0.5);
+      sfi_value_set_int (value, self->volume_factor * 100.0 + 0.5);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (self, param_id, pspec);
@@ -379,15 +374,15 @@ bse_midi_synth_context_create (BseSource *source,
 {
   BseMidiSynth *self = BSE_MIDI_SYNTH (source);
   BseSNet *snet = BSE_SNET (self);
-
+  
   /* chain parent class' handler */
   BSE_SOURCE_CLASS (parent_class)->context_create (source, context_handle, trans);
-
+  
   if (!bse_snet_context_is_branch (snet, context_handle))	/* catch recursion */
     {
       BseMidiReceiver *mrec;
       guint i, midi_channel;
-
+      
       mrec = bse_snet_get_midi_receiver (snet, context_handle, &midi_channel);
       for (i = 0; i < self->n_voices; i++)
 	bse_snet_context_clone_branch (snet, context_handle, self->context_merger, mrec, midi_channel, trans);
