@@ -142,35 +142,45 @@ bse_pcm_device_oss_open (BsePcmDevice *pdev)
   handle->read = NULL;
   handle->write = NULL;
   handle->status = NULL;
-  oss->fd = -1;
   oss->n_frags = 256;
   oss->frag_size = 512;
   oss->bytes_per_value = 2;
   oss->frag_buf = NULL;
-  
+  oss->fd = -1;
+
   /* try open */
   if (!error)
     {
-      gint omode, fd;
-
-      g_assert (handle->readable && handle->writable);
-      omode = O_RDWR | O_NONBLOCK;
-      /* need to open explicitely non-blocking or we'll have to wait until someone else closes the device */
-      fd = open (BSE_PCM_DEVICE_OSS (pdev)->device_name, omode, 0);
-      if (fd < 0)
+      struct { gchar *postfix; gint mode; } devices[] = {
+	{  "", O_RDWR, }, {  "", O_WRONLY, }, // {  "", O_RDONLY, },
+	{ "0", O_RDWR, }, { "0", O_WRONLY, }, // { "0", O_RDONLY, },
+	{ "1", O_RDWR, }, { "1", O_WRONLY, }, // { "1", O_RDONLY, },
+	{ "2", O_RDWR, }, { "2", O_WRONLY, }, // { "2", O_RDONLY, },
+	{ "3", O_RDWR, }, { "3", O_WRONLY, }, // { "3", O_RDONLY, },
+      };
+      guint i;
+      for (i = 0; i < G_N_ELEMENTS (devices) && oss->fd < 0; i++)
 	{
-	  /* retry without recording */
-	  handle->readable = FALSE;
-	  g_assert (handle->readable == FALSE && handle->writable);
-	  omode = O_WRONLY | O_NONBLOCK;
-	  fd = open (BSE_PCM_DEVICE_OSS (pdev)->device_name, omode, 0);
+	  gint fd, omode = devices[i].mode | O_NONBLOCK; /* non blocking to avoid waiting for other clients */
+	  gchar *dname = g_strconcat (BSE_PCM_DEVICE_OSS (pdev)->device_name, devices[i].postfix, NULL);
+	  fd = open (dname, omode, 0);
+	  if (fd >= 0)
+	    {
+	      oss->fd = fd;
+	      error = 0;
+	      handle->writable = (devices[i].mode == O_RDWR || devices[i].mode == O_WRONLY);
+	      handle->readable = (devices[i].mode == O_RDWR || devices[i].mode == O_RDONLY);
+	    }
+	  else
+	    {
+	      // g_printerr ("open(\"%s\") failed: %s\n", dname, g_strerror (errno));
+	      if (!error)
+		error = bse_error_from_errno (errno, BSE_ERROR_FILE_OPEN_FAILED);
+	    }
+	  g_free (dname);
 	}
-      if (fd >= 0)
-	oss->fd = fd;
-      else
-	error = bse_error_from_errno (errno, BSE_ERROR_FILE_OPEN_FAILED);
     }
-  
+
   /* try setup */
   if (!error)
     error = oss_device_setup (oss);
