@@ -136,30 +136,27 @@
 #define bse_source_clear_outputs foo_prefix_bse_source_clear_outputs
 #define bse_source_has_outputs foo_prefix_bse_source_has_outputs
 #define bse_source_ichannel_blurb foo_prefix_bse_source_ichannel_blurb
-#define bse_source_ichannel_cname foo_prefix_bse_source_ichannel_cname
 #define bse_source_ichannel_get_n_joints foo_prefix_bse_source_ichannel_get_n_joints
 #define bse_source_ichannel_get_ochannel foo_prefix_bse_source_ichannel_get_ochannel
 #define bse_source_ichannel_get_osource foo_prefix_bse_source_ichannel_get_osource
+#define bse_source_ichannel_ident foo_prefix_bse_source_ichannel_ident
 #define bse_source_ichannel_name foo_prefix_bse_source_ichannel_name
 #define bse_source_is_joint_ichannel foo_prefix_bse_source_is_joint_ichannel
 #define bse_source_is_joint_ichannel_by_id foo_prefix_bse_source_is_joint_ichannel_by_id
 #define bse_source_n_ichannels foo_prefix_bse_source_n_ichannels
 #define bse_source_n_ochannels foo_prefix_bse_source_n_ochannels
 #define bse_source_ochannel_blurb foo_prefix_bse_source_ochannel_blurb
-#define bse_source_ochannel_cname foo_prefix_bse_source_ochannel_cname
+#define bse_source_ochannel_ident foo_prefix_bse_source_ochannel_ident
 #define bse_source_ochannel_name foo_prefix_bse_source_ochannel_name
 #define bse_source_set_input foo_prefix_bse_source_set_input
 #define bse_source_set_input_by_id foo_prefix_bse_source_set_input_by_id
 #define bse_source_unset_input foo_prefix_bse_source_unset_input
 #define bse_source_unset_input_by_id foo_prefix_bse_source_unset_input_by_id
-#define bse_wave_chunk_get_mix_freq foo_prefix_bse_wave_chunk_get_mix_freq
-#define bse_wave_chunk_get_osc_freq foo_prefix_bse_wave_chunk_get_osc_freq
-#define bse_wave_load_wave foo_prefix_bse_wave_load_wave
-#define bse_wave_n_wave_chunks foo_prefix_bse_wave_n_wave_chunks
-#define bse_wave_use_editable foo_prefix_bse_wave_use_editable
 #define bse_container_get_item foo_prefix_bse_container_get_item
 #define bse_container_list_items foo_prefix_bse_container_list_items
 #define bse_container_lookup_item foo_prefix_bse_container_lookup_item
+#define bse_wave_repo_load_file foo_prefix_bse_wave_repo_load_file
+#define bse_wave_repo_remove_wave foo_prefix_bse_wave_repo_remove_wave
 #define bse_snet_can_create_source foo_prefix_bse_snet_can_create_source
 #define bse_snet_create_source foo_prefix_bse_snet_create_source
 #define bse_snet_remove_source foo_prefix_bse_snet_remove_source
@@ -171,8 +168,6 @@
 #define bse_song_remove_part foo_prefix_bse_song_remove_part
 #define bse_song_remove_track foo_prefix_bse_song_remove_track
 #define bse_song_synthesize_note foo_prefix_bse_song_synthesize_note
-#define bse_wave_repo_load_file foo_prefix_bse_wave_repo_load_file
-#define bse_wave_repo_remove_wave foo_prefix_bse_wave_repo_remove_wave
 #define bse_project_restore_from_file foo_prefix_bse_project_restore_from_file
 #define bse_project_store_bse foo_prefix_bse_project_store_bse
 #define bse_project_activate foo_prefix_bse_project_activate
@@ -208,32 +203,17 @@
 #define bse_server_use_new_project foo_prefix_bse_server_use_new_project
 #define bse_wave_osc_pcm_seek_perc foo_prefix_bse_wave_osc_pcm_seek_perc
 #define bse_wave_osc_request_pcm_position foo_prefix_bse_wave_osc_request_pcm_position
-#define bse_janitor_add_action foo_prefix_bse_janitor_add_action
-#define bse_janitor_exit foo_prefix_bse_janitor_exit
-#define bse_janitor_get_action foo_prefix_bse_janitor_get_action
-#define bse_janitor_get_action_blurb foo_prefix_bse_janitor_get_action_blurb
-#define bse_janitor_get_action_name foo_prefix_bse_janitor_get_action_name
-#define bse_janitor_get_proc_name foo_prefix_bse_janitor_get_proc_name
-#define bse_janitor_get_script_name foo_prefix_bse_janitor_get_script_name
-#define bse_janitor_kill foo_prefix_bse_janitor_kill
-#define bse_janitor_n_actions foo_prefix_bse_janitor_n_actions
-#define bse_janitor_progress foo_prefix_bse_janitor_progress
-#define bse_janitor_remove_action foo_prefix_bse_janitor_remove_action
-#define bse_janitor_set_msg foo_prefix_bse_janitor_set_msg
-#define bse_janitor_trigger_action foo_prefix_bse_janitor_trigger_action
+#define bse_wave_chunk_get_mix_freq foo_prefix_bse_wave_chunk_get_mix_freq
+#define bse_wave_chunk_get_osc_freq foo_prefix_bse_wave_chunk_get_osc_freq
+#define bse_wave_load_wave foo_prefix_bse_wave_load_wave
+#define bse_wave_n_wave_chunks foo_prefix_bse_wave_n_wave_chunks
+#define bse_wave_use_editable foo_prefix_bse_wave_use_editable
 #define bse_midi_notifier_current_time foo_prefix_bse_midi_notifier_current_time
-#define bse_data_pocket_create_entry foo_prefix_bse_data_pocket_create_entry
-#define bse_data_pocket_delete_entry foo_prefix_bse_data_pocket_delete_entry
-#define bse_data_pocket_get_float foo_prefix_bse_data_pocket_get_float
-#define bse_data_pocket_get_int foo_prefix_bse_data_pocket_get_int
-#define bse_data_pocket_get_n_entries foo_prefix_bse_data_pocket_get_n_entries
-#define bse_data_pocket_get_nth_entry_id foo_prefix_bse_data_pocket_get_nth_entry_id
-#define bse_data_pocket_get_object foo_prefix_bse_data_pocket_get_object
-#define bse_data_pocket_get_string foo_prefix_bse_data_pocket_get_string
-#define bse_data_pocket_set_float foo_prefix_bse_data_pocket_set_float
-#define bse_data_pocket_set_int foo_prefix_bse_data_pocket_set_int
-#define bse_data_pocket_set_object foo_prefix_bse_data_pocket_set_object
-#define bse_data_pocket_set_string foo_prefix_bse_data_pocket_set_string
+#define bse_track_get_part foo_prefix_bse_track_get_part
+#define bse_track_get_timing foo_prefix_bse_track_get_timing
+#define bse_track_insert_part foo_prefix_bse_track_insert_part
+#define bse_track_list_parts foo_prefix_bse_track_list_parts
+#define bse_track_remove_tick foo_prefix_bse_track_remove_tick
 #define bse_part_change_note foo_prefix_bse_part_change_note
 #define bse_part_check_overlap foo_prefix_bse_part_check_overlap
 #define bse_part_delete_event foo_prefix_bse_part_delete_event
@@ -252,11 +232,31 @@
 #define bse_part_select_event foo_prefix_bse_part_select_event
 #define bse_part_select_rectangle foo_prefix_bse_part_select_rectangle
 #define bse_part_select_rectangle_exclusive foo_prefix_bse_part_select_rectangle_exclusive
-#define bse_track_get_part foo_prefix_bse_track_get_part
-#define bse_track_get_timing foo_prefix_bse_track_get_timing
-#define bse_track_insert_part foo_prefix_bse_track_insert_part
-#define bse_track_list_parts foo_prefix_bse_track_list_parts
-#define bse_track_remove_tick foo_prefix_bse_track_remove_tick
+#define bse_data_pocket_create_entry foo_prefix_bse_data_pocket_create_entry
+#define bse_data_pocket_delete_entry foo_prefix_bse_data_pocket_delete_entry
+#define bse_data_pocket_get_float foo_prefix_bse_data_pocket_get_float
+#define bse_data_pocket_get_int foo_prefix_bse_data_pocket_get_int
+#define bse_data_pocket_get_n_entries foo_prefix_bse_data_pocket_get_n_entries
+#define bse_data_pocket_get_nth_entry_id foo_prefix_bse_data_pocket_get_nth_entry_id
+#define bse_data_pocket_get_object foo_prefix_bse_data_pocket_get_object
+#define bse_data_pocket_get_string foo_prefix_bse_data_pocket_get_string
+#define bse_data_pocket_set_float foo_prefix_bse_data_pocket_set_float
+#define bse_data_pocket_set_int foo_prefix_bse_data_pocket_set_int
+#define bse_data_pocket_set_object foo_prefix_bse_data_pocket_set_object
+#define bse_data_pocket_set_string foo_prefix_bse_data_pocket_set_string
+#define bse_janitor_add_action foo_prefix_bse_janitor_add_action
+#define bse_janitor_exit foo_prefix_bse_janitor_exit
+#define bse_janitor_get_action foo_prefix_bse_janitor_get_action
+#define bse_janitor_get_action_blurb foo_prefix_bse_janitor_get_action_blurb
+#define bse_janitor_get_action_name foo_prefix_bse_janitor_get_action_name
+#define bse_janitor_get_proc_name foo_prefix_bse_janitor_get_proc_name
+#define bse_janitor_get_script_name foo_prefix_bse_janitor_get_script_name
+#define bse_janitor_kill foo_prefix_bse_janitor_kill
+#define bse_janitor_n_actions foo_prefix_bse_janitor_n_actions
+#define bse_janitor_progress foo_prefix_bse_janitor_progress
+#define bse_janitor_remove_action foo_prefix_bse_janitor_remove_action
+#define bse_janitor_set_msg foo_prefix_bse_janitor_set_msg
+#define bse_janitor_trigger_action foo_prefix_bse_janitor_trigger_action
 #define bse_editable_sample_close foo_prefix_bse_editable_sample_close
 #define bse_editable_sample_collect_stats foo_prefix_bse_editable_sample_collect_stats
 #define bse_editable_sample_get_length foo_prefix_bse_editable_sample_get_length
@@ -622,38 +622,41 @@ extern SfiRecFields bse_gconfig_fields;
 
 #define BSE_IS_ITEM(proxy) bse_proxy_is_a ((proxy), "BseItem")
 #define BSE_IS_SOURCE(proxy) bse_proxy_is_a ((proxy), "BseSource")
-#define BSE_IS_WAVE(proxy) bse_proxy_is_a ((proxy), "BseWave")
-#define BSE_IS_CONTEXT_MERGER(proxy) bse_proxy_is_a ((proxy), "BseContextMerger")
-#define BSE_IS_AMPLIFIER(proxy) bse_proxy_is_a ((proxy), "BseAmplifier")
+#define BSE_IS_SNOOPER(proxy) bse_proxy_is_a ((proxy), "BseSnooper")
+#define BSE_IS_CONSTANT(proxy) bse_proxy_is_a ((proxy), "BseConstant")
 #define BSE_IS_CONTAINER(proxy) bse_proxy_is_a ((proxy), "BseContainer")
 #define BSE_IS_SUPER(proxy) bse_proxy_is_a ((proxy), "BseSuper")
-#define BSE_IS_SNET(proxy) bse_proxy_is_a ((proxy), "BseSNet")
-#define BSE_IS_SONG(proxy) bse_proxy_is_a ((proxy), "BseSong")
-#define BSE_IS_MIDI_SYNTH(proxy) bse_proxy_is_a ((proxy), "BseMidiSynth")
 #define BSE_IS_WAVE_REPO(proxy) bse_proxy_is_a ((proxy), "BseWaveRepo")
+#define BSE_IS_SNET(proxy) bse_proxy_is_a ((proxy), "BseSNet")
+#define BSE_IS_MIDI_SYNTH(proxy) bse_proxy_is_a ((proxy), "BseMidiSynth")
+#define BSE_IS_SONG(proxy) bse_proxy_is_a ((proxy), "BseSong")
 #define BSE_IS_PROJECT(proxy) bse_proxy_is_a ((proxy), "BseProject")
 #define BSE_IS_SERVER(proxy) bse_proxy_is_a ((proxy), "BseServer")
+#define BSE_IS_WAVE_OSC(proxy) bse_proxy_is_a ((proxy), "BseWaveOsc")
 #define BSE_IS_MIDI_ICONTROLLER(proxy) bse_proxy_is_a ((proxy), "BseMidiIController")
+#define BSE_IS_MIDI_VOICE_INPUT(proxy) bse_proxy_is_a ((proxy), "BseMidiVoiceInput")
+#define BSE_IS_CONTEXT_MERGER(proxy) bse_proxy_is_a ((proxy), "BseContextMerger")
 #define BSE_IS_SUB_IPORT(proxy) bse_proxy_is_a ((proxy), "BseSubIPort")
 #define BSE_IS_SUB_KEYBOARD(proxy) bse_proxy_is_a ((proxy), "BseSubKeyboard")
-#define BSE_IS_PCM_INPUT(proxy) bse_proxy_is_a ((proxy), "BsePcmInput")
-#define BSE_IS_WAVE_OSC(proxy) bse_proxy_is_a ((proxy), "BseWaveOsc")
-#define BSE_IS_SNOOPER(proxy) bse_proxy_is_a ((proxy), "BseSnooper")
+#define BSE_IS_BIQUAD_FILTER(proxy) bse_proxy_is_a ((proxy), "BseBiquadFilter")
+#define BSE_IS_SUB_SYNTH(proxy) bse_proxy_is_a ((proxy), "BseSubSynth")
+#define BSE_IS_STANDARD_OSC(proxy) bse_proxy_is_a ((proxy), "BseStandardOsc")
 #define BSE_IS_PCM_OUTPUT(proxy) bse_proxy_is_a ((proxy), "BsePcmOutput")
-#define BSE_IS_MIDI_VOICE_INPUT(proxy) bse_proxy_is_a ((proxy), "BseMidiVoiceInput")
+#define BSE_IS_PCM_INPUT(proxy) bse_proxy_is_a ((proxy), "BsePcmInput")
 #define BSE_IS_SUB_OPORT(proxy) bse_proxy_is_a ((proxy), "BseSubOPort")
 #define BSE_IS_SUB_INSTRUMENT(proxy) bse_proxy_is_a ((proxy), "BseSubInstrument")
+#define BSE_IS_WAVE(proxy) bse_proxy_is_a ((proxy), "BseWave")
 #define BSE_IS_MIDI_VOICE_SWITCH(proxy) bse_proxy_is_a ((proxy), "BseMidiVoiceSwitch")
-#define BSE_IS_STANDARD_OSC(proxy) bse_proxy_is_a ((proxy), "BseStandardOsc")
-#define BSE_IS_SUB_SYNTH(proxy) bse_proxy_is_a ((proxy), "BseSubSynth")
-#define BSE_IS_CONSTANT(proxy) bse_proxy_is_a ((proxy), "BseConstant")
-#define BSE_IS_BIQUAD_FILTER(proxy) bse_proxy_is_a ((proxy), "BseBiquadFilter")
-#define BSE_IS_JANITOR(proxy) bse_proxy_is_a ((proxy), "BseJanitor")
+#define BSE_IS_LADSPA_MODULE(proxy) bse_proxy_is_a ((proxy), "BseLadspaModule")
+#define BSE_IS_AMPLIFIER(proxy) bse_proxy_is_a ((proxy), "BseAmplifier")
 #define BSE_IS_MIDI_NOTIFIER(proxy) bse_proxy_is_a ((proxy), "BseMidiNotifier")
-#define BSE_IS_DATA_POCKET(proxy) bse_proxy_is_a ((proxy), "BseDataPocket")
-#define BSE_IS_PART(proxy) bse_proxy_is_a ((proxy), "BsePart")
 #define BSE_IS_TRACK(proxy) bse_proxy_is_a ((proxy), "BseTrack")
+#define BSE_IS_PART(proxy) bse_proxy_is_a ((proxy), "BsePart")
+#define BSE_IS_DATA_POCKET(proxy) bse_proxy_is_a ((proxy), "BseDataPocket")
+#define BSE_IS_JANITOR(proxy) bse_proxy_is_a ((proxy), "BseJanitor")
 #define BSE_IS_EDITABLE_SAMPLE(proxy) bse_proxy_is_a ((proxy), "BseEditableSample")
+#define BSE_IS_PCM_DEVICE(proxy) bse_proxy_is_a ((proxy), "BsePcmDevice")
+#define BSE_IS_PCM_DEVICE_OSS(proxy) bse_proxy_is_a ((proxy), "BsePcmDeviceOSS")
 
 SfiBool bse_item_check_is_a (SfiProxy bse_item_object, const gchar* type_name);
 SfiProxy bse_item_common_ancestor (SfiProxy bse_item_object, SfiProxy item2);
@@ -677,30 +680,27 @@ void bse_source_clear_inputs (SfiProxy bse_source_object);
 void bse_source_clear_outputs (SfiProxy bse_source_object);
 SfiBool bse_source_has_outputs (SfiProxy bse_source_object);
 const gchar* bse_source_ichannel_blurb (SfiProxy bse_source_object, SfiInt input_channel);
-const gchar* bse_source_ichannel_cname (SfiProxy bse_source_object, SfiInt input_channel);
 SfiInt bse_source_ichannel_get_n_joints (SfiProxy bse_source_object, SfiInt input_channel);
 SfiInt bse_source_ichannel_get_ochannel (SfiProxy bse_source_object, SfiInt input_channel, SfiInt input_joint);
 SfiProxy bse_source_ichannel_get_osource (SfiProxy bse_source_object, SfiInt input_channel, SfiInt input_joint);
+const gchar* bse_source_ichannel_ident (SfiProxy bse_source_object, SfiInt input_channel);
 const gchar* bse_source_ichannel_name (SfiProxy bse_source_object, SfiInt input_channel);
 SfiBool bse_source_is_joint_ichannel (SfiProxy bse_source_object, const gchar* input_channel);
 SfiBool bse_source_is_joint_ichannel_by_id (SfiProxy bse_source_object, SfiInt input_channel);
 SfiInt bse_source_n_ichannels (SfiProxy bse_source_object);
 SfiInt bse_source_n_ochannels (SfiProxy bse_source_object);
 const gchar* bse_source_ochannel_blurb (SfiProxy bse_source_object, SfiInt input_channel);
-const gchar* bse_source_ochannel_cname (SfiProxy bse_source_object, SfiInt input_channel);
+const gchar* bse_source_ochannel_ident (SfiProxy bse_source_object, SfiInt input_channel);
 const gchar* bse_source_ochannel_name (SfiProxy bse_source_object, SfiInt input_channel);
 BseErrorType bse_source_set_input (SfiProxy bse_source_object, const gchar* input_channel, SfiProxy omodule, const gchar* output_channel);
 BseErrorType bse_source_set_input_by_id (SfiProxy bse_source_object, SfiInt input_channel, SfiProxy omodule, SfiInt output_channel);
 BseErrorType bse_source_unset_input (SfiProxy bse_source_object, const gchar* input_channel, SfiProxy omodule, const gchar* output_channel);
 BseErrorType bse_source_unset_input_by_id (SfiProxy bse_source_object, SfiInt input_channel, SfiProxy omodule, SfiInt output_channel);
-SfiReal bse_wave_chunk_get_mix_freq (SfiProxy bse_wave_object, SfiInt chunk_index);
-SfiReal bse_wave_chunk_get_osc_freq (SfiProxy bse_wave_object, SfiInt chunk_index);
-BseErrorType bse_wave_load_wave (SfiProxy bse_wave_object, const gchar* file_name, const gchar* wave_name);
-SfiInt bse_wave_n_wave_chunks (SfiProxy bse_wave_object);
-SfiProxy bse_wave_use_editable (SfiProxy bse_wave_object, SfiInt chunk_index);
 SfiProxy bse_container_get_item (SfiProxy bse_container_object, const gchar* item_type, SfiInt seq_id);
 BseProxySeq* bse_container_list_items (SfiProxy bse_container_object);
 SfiProxy bse_container_lookup_item (SfiProxy bse_container_object, const gchar* uname);
+BseErrorType bse_wave_repo_load_file (SfiProxy bse_wave_repo_object, const gchar* file_name);
+void bse_wave_repo_remove_wave (SfiProxy bse_wave_repo_object, SfiProxy wave);
 BseErrorType bse_snet_can_create_source (SfiProxy bse_snet_object, const gchar* module_type);
 SfiProxy bse_snet_create_source (SfiProxy bse_snet_object, const gchar* module_type);
 BseErrorType bse_snet_remove_source (SfiProxy bse_snet_object, SfiProxy module);
@@ -712,8 +712,6 @@ BseSongTiming* bse_song_get_timing (SfiProxy bse_song_object, SfiInt tick);
 void bse_song_remove_part (SfiProxy bse_song_object, SfiProxy part);
 void bse_song_remove_track (SfiProxy bse_song_object, SfiProxy track);
 void bse_song_synthesize_note (SfiProxy bse_song_object, SfiProxy track, SfiInt duration, SfiInt note, SfiInt fine_tune, SfiReal velocity);
-BseErrorType bse_wave_repo_load_file (SfiProxy bse_wave_repo_object, const gchar* file_name);
-void bse_wave_repo_remove_wave (SfiProxy bse_wave_repo_object, SfiProxy wave);
 BseErrorType bse_project_restore_from_file (SfiProxy bse_project_object, const gchar* file_name);
 BseErrorType bse_project_store_bse (SfiProxy bse_project_object, const gchar* file_name, SfiBool self_contained);
 BseErrorType bse_project_activate (SfiProxy bse_project_object);
@@ -749,32 +747,17 @@ void bse_server_save_preferences (SfiProxy bse_server_object);
 SfiProxy bse_server_use_new_project (SfiProxy bse_server_object, const gchar* name);
 void bse_wave_osc_pcm_seek_perc (SfiProxy bse_wave_osc_object, SfiReal pos_perc);
 void bse_wave_osc_request_pcm_position (SfiProxy bse_wave_osc_object);
-void bse_janitor_add_action (SfiProxy bse_janitor_object, const gchar* action, const gchar* name, const gchar* blurb);
-void bse_janitor_exit (SfiProxy bse_janitor_object, BseUserMsgType msg_type, const gchar* message);
-const gchar* bse_janitor_get_action (SfiProxy bse_janitor_object, SfiInt nth_action);
-const gchar* bse_janitor_get_action_blurb (SfiProxy bse_janitor_object, SfiInt nth_action);
-const gchar* bse_janitor_get_action_name (SfiProxy bse_janitor_object, SfiInt nth_action);
-const gchar* bse_janitor_get_proc_name (SfiProxy bse_janitor_object);
-const gchar* bse_janitor_get_script_name (SfiProxy bse_janitor_object);
-void bse_janitor_kill (SfiProxy bse_janitor_object);
-SfiInt bse_janitor_n_actions (SfiProxy bse_janitor_object);
-void bse_janitor_progress (SfiProxy bse_janitor_object, SfiReal progress);
-void bse_janitor_remove_action (SfiProxy bse_janitor_object, const gchar* action);
-void bse_janitor_set_msg (SfiProxy bse_janitor_object, BseUserMsgType msg_type, const gchar* message);
-void bse_janitor_trigger_action (SfiProxy bse_janitor_object, const gchar* action);
+SfiReal bse_wave_chunk_get_mix_freq (SfiProxy bse_wave_object, SfiInt chunk_index);
+SfiReal bse_wave_chunk_get_osc_freq (SfiProxy bse_wave_object, SfiInt chunk_index);
+BseErrorType bse_wave_load_wave (SfiProxy bse_wave_object, const gchar* file_name, const gchar* wave_name);
+SfiInt bse_wave_n_wave_chunks (SfiProxy bse_wave_object);
+SfiProxy bse_wave_use_editable (SfiProxy bse_wave_object, SfiInt chunk_index);
 SfiInt bse_midi_notifier_current_time (SfiProxy bse_midi_notifier_object);
-SfiInt bse_data_pocket_create_entry (SfiProxy bse_data_pocket_object);
-BseErrorType bse_data_pocket_delete_entry (SfiProxy bse_data_pocket_object, SfiInt entry_id);
-SfiReal bse_data_pocket_get_float (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name);
-SfiInt bse_data_pocket_get_int (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name);
-SfiInt bse_data_pocket_get_n_entries (SfiProxy bse_data_pocket_object);
-SfiInt bse_data_pocket_get_nth_entry_id (SfiProxy bse_data_pocket_object, SfiInt entry_index);
-SfiProxy bse_data_pocket_get_object (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name);
-const gchar* bse_data_pocket_get_string (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name);
-BseErrorType bse_data_pocket_set_float (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name, SfiReal number);
-BseErrorType bse_data_pocket_set_int (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name, SfiInt number);
-BseErrorType bse_data_pocket_set_object (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name, SfiProxy item);
-BseErrorType bse_data_pocket_set_string (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name, const gchar* string);
+SfiProxy bse_track_get_part (SfiProxy bse_track_object, SfiInt tick);
+BseSongTiming* bse_track_get_timing (SfiProxy bse_track_object, SfiInt tick);
+BseErrorType bse_track_insert_part (SfiProxy bse_track_object, SfiInt tick, SfiProxy part);
+BseTrackPartSeq* bse_track_list_parts (SfiProxy bse_track_object);
+void bse_track_remove_tick (SfiProxy bse_track_object, SfiInt tick);
 BseErrorType bse_part_change_note (SfiProxy bse_part_object, SfiInt id, SfiInt tick, SfiInt duration, SfiInt note, SfiInt fine_tune, SfiReal velocity);
 BsePartNoteSeq* bse_part_check_overlap (SfiProxy bse_part_object, SfiInt tick, SfiInt duration, SfiInt note);
 BseErrorType bse_part_delete_event (SfiProxy bse_part_object, SfiInt id);
@@ -793,11 +776,31 @@ void bse_part_queue_notes_within (SfiProxy bse_part_object, SfiInt tick, SfiInt
 void bse_part_select_event (SfiProxy bse_part_object, SfiInt id);
 void bse_part_select_rectangle (SfiProxy bse_part_object, SfiInt tick, SfiInt duration, SfiInt min_note, SfiInt max_note);
 void bse_part_select_rectangle_exclusive (SfiProxy bse_part_object, SfiInt tick, SfiInt duration, SfiInt min_note, SfiInt max_note);
-SfiProxy bse_track_get_part (SfiProxy bse_track_object, SfiInt tick);
-BseSongTiming* bse_track_get_timing (SfiProxy bse_track_object, SfiInt tick);
-BseErrorType bse_track_insert_part (SfiProxy bse_track_object, SfiInt tick, SfiProxy part);
-BseTrackPartSeq* bse_track_list_parts (SfiProxy bse_track_object);
-void bse_track_remove_tick (SfiProxy bse_track_object, SfiInt tick);
+SfiInt bse_data_pocket_create_entry (SfiProxy bse_data_pocket_object);
+BseErrorType bse_data_pocket_delete_entry (SfiProxy bse_data_pocket_object, SfiInt entry_id);
+SfiReal bse_data_pocket_get_float (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name);
+SfiInt bse_data_pocket_get_int (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name);
+SfiInt bse_data_pocket_get_n_entries (SfiProxy bse_data_pocket_object);
+SfiInt bse_data_pocket_get_nth_entry_id (SfiProxy bse_data_pocket_object, SfiInt entry_index);
+SfiProxy bse_data_pocket_get_object (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name);
+const gchar* bse_data_pocket_get_string (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name);
+BseErrorType bse_data_pocket_set_float (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name, SfiReal number);
+BseErrorType bse_data_pocket_set_int (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name, SfiInt number);
+BseErrorType bse_data_pocket_set_object (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name, SfiProxy item);
+BseErrorType bse_data_pocket_set_string (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name, const gchar* string);
+void bse_janitor_add_action (SfiProxy bse_janitor_object, const gchar* action, const gchar* name, const gchar* blurb);
+void bse_janitor_exit (SfiProxy bse_janitor_object, BseUserMsgType msg_type, const gchar* message);
+const gchar* bse_janitor_get_action (SfiProxy bse_janitor_object, SfiInt nth_action);
+const gchar* bse_janitor_get_action_blurb (SfiProxy bse_janitor_object, SfiInt nth_action);
+const gchar* bse_janitor_get_action_name (SfiProxy bse_janitor_object, SfiInt nth_action);
+const gchar* bse_janitor_get_proc_name (SfiProxy bse_janitor_object);
+const gchar* bse_janitor_get_script_name (SfiProxy bse_janitor_object);
+void bse_janitor_kill (SfiProxy bse_janitor_object);
+SfiInt bse_janitor_n_actions (SfiProxy bse_janitor_object);
+void bse_janitor_progress (SfiProxy bse_janitor_object, SfiReal progress);
+void bse_janitor_remove_action (SfiProxy bse_janitor_object, const gchar* action);
+void bse_janitor_set_msg (SfiProxy bse_janitor_object, BseUserMsgType msg_type, const gchar* message);
+void bse_janitor_trigger_action (SfiProxy bse_janitor_object, const gchar* action);
 void bse_editable_sample_close (SfiProxy bse_editable_sample_object);
 SfiFBlock* bse_editable_sample_collect_stats (SfiProxy bse_editable_sample_object, SfiInt voffset, SfiReal offset_scale, SfiInt block_size, SfiInt stepping, SfiInt max_pairs);
 SfiInt bse_editable_sample_get_length (SfiProxy bse_editable_sample_object);
